@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -76,13 +76,13 @@ public class FormatData_es_NI extends ListResourceBundle {
             };
         final Object[][] data = new Object[][] {
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
         };
