@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -80,6 +80,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "mwl", "\u0574\u056b\u0580\u0561\u0576\u0564\u0565\u0580\u0565\u0576" },
             { "Zsym", "\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
             { "Zsye", "\u0567\u0574\u0578\u0571\u056b" },
+            { "ccp", "\u0579\u0561\u056f\u0574\u0561" },
             { "egy", "\u0570\u056b\u0576 \u0565\u0563\u056b\u057a\u057f\u0565\u0580\u0565\u0576" },
             { "raj", "\u057c\u0561\u057b\u0561\u057d\u057f\u0561\u0576\u0565\u0580\u0565\u0576" },
             { "tem", "\u057f\u0565\u0574\u0576\u0565" },
@@ -950,6 +951,7 @@ public class LocaleNames_hy extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0569\u0561\u0574\u056b\u056c\u0561\u056f\u0561\u0576 \u0569\u057e\u0561\u0576\u0577\u0561\u0576\u0576\u0565\u0580" },
             { "krc", "\u056f\u0561\u0580\u0561\u0579\u0561\u0575-\u0562\u0561\u056c\u056f\u0561\u0580\u0565\u0580\u0565\u0576" },
             { "inh", "\u056b\u0576\u0563\u0578\u0582\u0577\u0565\u0580\u0565\u0576" },
+            { "fa_AF", "\u0564\u0561\u0580\u056b" },
             { "krl", "\u056f\u0561\u0580\u0565\u056c\u0565\u0580\u0565\u0576" },
             { "efi", "\u0567\u0586\u056b\u056f" },
             { "tcy", "\u057f\u0578\u0582\u056c\u0578\u0582" },
