@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -94,6 +94,7 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "mwl", "\u043c\u0435\u0440\u0430\u043d\u0434\u0438" },
             { "Zsym", "\u0442\u044d\u043c\u0434\u044d\u0433" },
             { "Zsye", "\u044d\u043c\u043e\u0436\u0438" },
+            { "ccp", "\u0447\u0430\u043a\u043c\u0430" },
             { "tem", "\u0442\u0438\u043c\u043d" },
             { "teo", "\u0442\u044d\u0441\u043e" },
             { "rap", "\u0440\u0430\u043f\u0430\u043d\u0443\u0438" },
@@ -295,6 +296,7 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "LB", "\u041b\u0438\u0432\u0430\u043d" },
             { "LC", "\u0421\u0435\u043d\u0442 \u041b\u044e\u0441\u0438\u0430" },
             { "gwi", "\u0433\u0432\u0438\u0447\u0438\u043d" },
+            { "nds", "\u0434\u043e\u043e\u0434 \u0433\u0435\u0440\u043c\u0430\u043d" },
             { "LI", "\u041b\u0438\u0445\u0442\u0435\u043d\u0448\u0442\u0435\u0439\u043d" },
             { "LK", "\u0428\u0440\u0438-\u041b\u0430\u043d\u043a\u0430" },
             { "LR", "\u041b\u0438\u0431\u0435\u0440\u0438" },
@@ -310,14 +312,14 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "Thaa", "\u0442\u0430\u043d\u0430" },
             { "MA", "\u041c\u043e\u0440\u043e\u043a\u043a\u043e" },
             { "MC", "\u041c\u043e\u043d\u0430\u043a\u043e" },
-            { "MD", "\u041c\u043e\u043b\u0434\u0430\u0432" },
+            { "MD", "\u041c\u043e\u043b\u0434\u043e\u0432\u0430" },
             { "ME", "\u041c\u043e\u043d\u0442\u0435\u043d\u0435\u0433\u0440\u043e" },
             { "MF", "\u0421\u0435\u043d\u0442-\u041c\u0430\u0440\u0442\u0438\u043d" },
             { "MG", "\u041c\u0430\u0434\u0430\u0433\u0430\u0441\u043a\u0430\u0440" },
             { "Thai", metaValue_th },
             { "MH", "\u041c\u0430\u0440\u0448\u0430\u043b\u043b\u044b\u043d \u0430\u0440\u043b\u0443\u0443\u0434" },
             { "ale", "\u0430\u043b\u044e\u0442" },
-            { "MK", "\u041c\u0430\u043a\u0435\u0434\u043e\u043d" },
+            { "MK", "\u0425\u043e\u0439\u0434 \u041c\u0430\u043a\u0435\u0434\u043e\u043d" },
             { "ML", "\u041c\u0430\u043b\u0438" },
             { "MM", "\u041c\u044c\u044f\u043d\u043c\u0430\u0440" },
             { "MN", "\u041c\u043e\u043d\u0433\u043e\u043b" },
@@ -423,7 +425,7 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "SV", "\u042d\u043b\u044c \u0421\u0430\u043b\u044c\u0432\u0430\u0434\u043e\u0440" },
             { "SX", "\u0421\u0438\u043d\u0442 \u041c\u0430\u0440\u0442\u0435\u043d" },
             { "SY", "\u0421\u0438\u0440\u0438" },
-            { "SZ", "\u0421\u0432\u0430\u0437\u0438\u043b\u0430\u043d\u0434" },
+            { "SZ", "\u042d\u0441\u0432\u0430\u0442\u0438\u043d\u0438" },
             { "TA", "\u0422\u0440\u0438\u0441\u0442\u0430\u043d \u0434\u0430 \u041a\u0443\u043d\u044a\u044f" },
             { "asa", "\u0430\u0441\u0443" },
             { "type.ms.ussystem", "\u0410\u043c\u0435\u0440\u0438\u043a \u043d\u044d\u0433\u0436\u0438\u0439\u043d \u0441\u0438\u0441\u0442\u0435\u043c" },
@@ -467,7 +469,7 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "UY", "\u0423\u0440\u0443\u0433\u0432\u0430\u0439" },
             { "prg", "\u043f\u0440\u0443\u0441\u0441" },
             { "UZ", "\u0423\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u0430\u043d" },
-            { "tzm", "\u0422\u04e9\u0432 \u0410\u0442\u043b\u0430\u0441\u044b\u043d \u0442\u0430\u043c\u0430\u0437\u0430\u0439\u0442" },
+            { "tzm", "\u0422\u04e9\u0432 \u0410\u0442\u043b\u0430\u0441\u044b\u043d \u0442\u0430\u043c\u0430\u0437\u0438\u0433\u0445\u0442" },
             { "nnh", "\u043d\u0433\u0438\u0435\u043c\u0431\u04af\u04af\u043d" },
             { "VA", "\u0412\u0430\u0442\u0438\u043a\u0430\u043d \u0445\u043e\u0442 \u0443\u043b\u0441" },
             { "VC", "\u0421\u0435\u043d\u0442-\u0412\u0438\u043d\u0441\u0435\u043d\u0442 \u0431\u0430 \u0413\u0440\u0435\u043d\u0430\u0434\u0438\u043d" },
@@ -487,7 +489,9 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "wae", "\u0443\u043e\u043b\u0441\u044d\u0440" },
             { "WS", "\u0421\u0430\u043c\u043e\u0430" },
             { "wal", "\u0443\u043e\u043b\u043b\u0430\u0439\u0442\u0442\u0430" },
+            { "XA", "\u0445\u0443\u0443\u0440\u043c\u0430\u0433 \u0430\u044f\u043b\u0433\u0430" },
             { "war", "\u0432\u0430\u0440\u0430\u0439" },
+            { "XB", "\u0445\u0443\u0443\u0440\u043c\u0430\u0433 \u0445\u043e\u0451\u0440 \u0447\u0438\u0433\u043b\u044d\u043b\u0442" },
             { "awa", "\u0430\u0432\u0430\u0434\u0445\u0438" },
             { "061", "\u041f\u043e\u043b\u0438\u043d\u0435\u0437\u0438" },
             { "XK", "\u041a\u043e\u0441\u043e\u0432\u043e" },
@@ -516,7 +520,7 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "type.nu.arabext", "\u04e9\u0440\u0433\u04e9\u0442\u0433\u04e9\u0441\u04e9\u043d \u0430\u0440\u0430\u0431-\u044d\u043d\u044d\u0442\u0445\u044d\u0433 \u0442\u043e\u043e" },
             { "nus", "\u043d\u0443\u0435\u0440" },
             { "dak", "\u0434\u0430\u043a\u043e\u0442\u0430" },
-            { "type.nu.fullwide", "\u0431\u04af\u0440\u044d\u043d \u0445\u044d\u043c\u0436\u044d\u044d\u0442\u044d\u0439 \u0442\u043e\u043e" },
+            { "type.nu.fullwide", "\u0431\u04af\u0442\u044d\u043d-\u04e9\u0440\u0433\u04e9\u043d\u0442\u044d\u0439 \u0442\u043e\u043e" },
             { "dar", "\u0434\u0430\u0440\u0433\u0432\u0430" },
             { "dav", "\u0442\u0430\u0439\u0442\u0430" },
             { "lrc", "\u0445\u043e\u0439\u0434 \u043b\u0443\u0440\u0438" },
@@ -842,7 +846,7 @@ public class LocaleNames_mn extends OpenListResourceBundle {
             { "syr", "\u0441\u0438\u0440\u0438" },
             { "Grek", metaValue_el },
             { "wo", "\u0432\u043e\u043b\u043e\u0444" },
-            { "zgh", "\u041c\u043e\u0440\u043e\u043a\u043a\u043e\u0433\u0438\u0439\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0442\u0430\u043c\u0430\u0437\u0430\u0439\u0442" },
+            { "zgh", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0442\u0430\u043c\u0430\u0437\u0430\u0439\u0442 (\u041c\u043e\u0440\u043e\u043a\u043a\u043e)" },
             { "ar_001", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0430\u0440\u0430\u0431" },
             { "Mong", "\u043c\u043e\u043d\u0433\u043e\u043b \u0431\u0438\u0447\u0438\u0433" },
             { "mni", "\u043c\u0430\u043d\u0438\u043f\u0443\u0440\u0438" },
