@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -100,6 +100,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
         final String metaValue_bas = "\u5df4\u85a9\u6587";
         final String metaValue_bax = "\u5df4\u59c6\u7a46\u6587";
         final String metaValue_bug = "\u5e03\u5409\u65af\u6587";
+        final String metaValue_ccp = "\u67e5\u514b\u99ac\u6587";
         final String metaValue_chr = "\u67f4\u7f85\u57fa\u6587";
         final String metaValue_cop = "\u79d1\u666e\u7279\u6587";
         final String metaValue_gon = "\u5ca1\u5fb7\u6587";
@@ -130,6 +131,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "Tagb", "\u5357\u5cf6\u6587" },
             { "%%NJIVA", "\u96f7\u897f\u4e9e\u5c3c\u74e6\u65b9\u8a00" },
             { "xmf", "\u660e\u683c\u5217\u723e\u6587" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u53e4\u57c3\u53ca\u6587" },
             { "raj", "\u62c9\u8cc8\u65af\u5766\u8af8\u6587" },
             { "Phag", "\u516b\u601d\u5df4\u6587" },
@@ -458,7 +460,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "MH", "\u99ac\u7d39\u723e\u7fa4\u5cf6" },
             { "ale", "\u963f\u7559\u7533\u6587" },
             { "type.nu.vaii", "\u74e6\u4f0a\u6587\u6578\u5b57" },
-            { "MK", "\u99ac\u5176\u9813" },
+            { "MK", "\u5317\u99ac\u5176\u9813" },
             { "type.nu.mathdbl", "\u6578\u5b78\u96d9\u91cd\u6578\u5b57" },
             { "ML", "\u99ac\u5229" },
             { "MM", "\u7dec\u7538" },
@@ -543,7 +545,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "tum", "\u5716\u59c6\u5e03\u5361\u6587" },
             { "Hebr", metaValue_he },
             { "QA", "\u5361\u9054" },
-            { "%%SCOTLAND", "\u82f1\u6587\uff08\u8607\u683c\u862d\uff09" },
+            { "%%SCOTLAND", "\u8607\u683c\u862d\u6a19\u6e96\u82f1\u6587" },
             { "jam", "\u7259\u8cb7\u52a0\u514b\u91cc\u5967\u723e\u82f1\u6587" },
             { "pms", "\u76ae\u57c3\u8499\u7279\u6587" },
             { "niu", "\u7d10\u57c3\u6587" },
@@ -621,7 +623,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "SX", "\u8377\u5c6c\u8056\u99ac\u4e01" },
             { "SY", "\u6558\u5229\u4e9e" },
             { "yao", "\u7464\u6587" },
-            { "SZ", "\u53f2\u74e6\u6fdf\u862d" },
+            { "SZ", "\u53f2\u74e6\u5e1d\u5c3c" },
             { "arw", "\u963f\u62c9\u74e6\u514b\u6587" },
             { "arz", "\u57c3\u53ca\u963f\u62c9\u4f2f\u6587" },
             { "ary", "\u6469\u6d1b\u54e5\u963f\u62c9\u4f2f\u6587" },
@@ -634,6 +636,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "TC", "\u571f\u514b\u65af\u53ca\u958b\u79d1\u65af\u7fa4\u5cf6" },
             { "yav", "\u6d0b\u535e\u6587" },
             { "TD", "\u67e5\u5fb7" },
+            { "Qaag", "\u4f50\u57fa\u6587" },
             { "TF", "\u6cd5\u5c6c\u5357\u90e8\u5c6c\u5730" },
             { "ase", "\u7f8e\u570b\u624b\u8a9e" },
             { "TG", "\u591a\u54e5" },
@@ -720,7 +723,9 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "type.nu.mtei", "\u66fc\u5c3c\u666e\u723e\u6578\u5b57" },
             { "wal", "\u74e6\u62c9\u83ab\u6587" },
             { "was", "\u74e6\u7d39\u6587" },
+            { "XA", "\u507d\u5340\u57df" },
             { "war", "\u74e6\u745e\u6587" },
+            { "XB", "\u507d\u6bd4\u8fea" },
             { "awa", "\u963f\u74e6\u6587" },
             { "061", "\u73bb\u91cc\u5c3c\u897f\u4e9e" },
             { "%%KSCOR", "\u6a19\u6e96\u62fc\u5beb" },
@@ -836,6 +841,7 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "scn", "\u897f\u897f\u91cc\u6587" },
             { "aa", "\u963f\u6cd5\u6587" },
             { "ab", "\u963f\u5e03\u54c8\u8332\u6587" },
+            { "Aran", "\u6ce2\u65af\u9ad4" },
             { "bbc", "\u5df4\u5854\u514b\u6258\u5df4\u6587" },
             { "ae", "\u963f\u7dad\u65af\u5854\u6587" },
             { "af", "\u5357\u975e\u8377\u862d\u6587" },
@@ -1231,9 +1237,9 @@ public class LocaleNames_zh_Hant extends OpenListResourceBundle {
             { "dyo", "\u6731\u62c9\u6587" },
             { "type.nu.jpan", "\u5c0f\u5beb\u65e5\u6587\u6578\u5b57" },
             { "tr", "\u571f\u8033\u5176\u6587" },
+            { "Cakm", metaValue_ccp },
             { "ts", "\u7279\u677e\u52a0\u6587" },
             { "swb", "\u845b\u6469\u6587" },
-            { "Cakm", "\u67e5\u514b\u99ac\u6587" },
             { "tt", "\u97c3\u977c\u6587" },
             { "dyu", "\u8fea\u5c24\u62c9\u6587" },
             { "tw", "\u7279\u5a01\u6587" },
